==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/privacy/PrivacyEventsServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.privacy;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: privacy/privacy_events_service.proto")
public final class PrivacyEventsServiceGrpc {

  private PrivacyEventsServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.PrivacyEventsService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "SubscribeOn",
      requestType = com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.class,
      responseType = com.wavesenterprise.protobuf.service.privacy.PrivacyEvent.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod;
    if ((getSubscribeOnMethod = PrivacyEventsServiceGrpc.getSubscribeOnMethod) == null) {
      synchronized (PrivacyEventsServiceGrpc.class) {
        if ((getSubscribeOnMethod = PrivacyEventsServiceGrpc.getSubscribeOnMethod) == null) {
          PrivacyEventsServiceGrpc.getSubscribeOnMethod = getSubscribeOnMethod = 
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.PrivacyEventsService", "SubscribeOn"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.privacy.PrivacyEvent.getDefaultInstance()))
                  .setSchemaDescriptor(new PrivacyEventsServiceMethodDescriptorSupplier("SubscribeOn"))
                  .build();
          }
        }
     }
     return getSubscribeOnMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PrivacyEventsServiceStub newStub(io.grpc.Channel channel) {
    return new PrivacyEventsServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PrivacyEventsServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new PrivacyEventsServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PrivacyEventsServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new PrivacyEventsServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class PrivacyEventsServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> responseObserver) {
      asyncUnimplementedUnaryCall(getSubscribeOnMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubscribeOnMethod(),
            asyncServerStreamingCall(
              new MethodHandlers<
                com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
                com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>(
                  this, METHODID_SUBSCRIBE_ON)))
          .build();
    }
  }

  /**
   */
  public static final class PrivacyEventsServiceStub extends io.grpc.stub.AbstractStub<PrivacyEventsServiceStub> {
    private PrivacyEventsServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PrivacyEventsServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceStub(channel, callOptions);
    }

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> responseObserver) {
      asyncServerStreamingCall(
          getChannel().newCall(getSubscribeOnMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class PrivacyEventsServiceBlockingStub extends io.grpc.stub.AbstractStub<PrivacyEventsServiceBlockingStub> {
    private PrivacyEventsServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PrivacyEventsServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> subscribeOn(
        com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request) {
      return blockingServerStreamingCall(
          getChannel(), getSubscribeOnMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class PrivacyEventsServiceFutureStub extends io.grpc.stub.AbstractStub<PrivacyEventsServiceFutureStub> {
    private PrivacyEventsServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PrivacyEventsServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_ON = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final PrivacyEventsServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(PrivacyEventsServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_ON:
          serviceImpl.subscribeOn((com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class PrivacyEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PrivacyEventsServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.privacy.PrivacyEventsServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PrivacyEventsService");
    }
  }

  private static final class PrivacyEventsServiceFileDescriptorSupplier
      extends PrivacyEventsServiceBaseDescriptorSupplier {
    PrivacyEventsServiceFileDescriptorSupplier() {}
  }

  private static final class PrivacyEventsServiceMethodDescriptorSupplier
      extends PrivacyEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    PrivacyEventsServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PrivacyEventsServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PrivacyEventsServiceFileDescriptorSupplier())
              .addMethod(getSubscribeOnMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/privacy/PrivacyEventsServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.privacy;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: privacy/privacy_events_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PrivacyEventsServiceGrpc {

  private PrivacyEventsServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.PrivacyEventsService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "SubscribeOn",
      requestType = com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.class,
      responseType = com.wavesenterprise.protobuf.service.privacy.PrivacyEvent.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> getSubscribeOnMethod;
    if ((getSubscribeOnMethod = PrivacyEventsServiceGrpc.getSubscribeOnMethod) == null) {
      synchronized (PrivacyEventsServiceGrpc.class) {
        if ((getSubscribeOnMethod = PrivacyEventsServiceGrpc.getSubscribeOnMethod) == null) {
          PrivacyEventsServiceGrpc.getSubscribeOnMethod = getSubscribeOnMethod =
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "SubscribeOn"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.privacy.PrivacyEvent.getDefaultInstance()))
              .setSchemaDescriptor(new PrivacyEventsServiceMethodDescriptorSupplier("SubscribeOn"))
              .build();
        }
      }
    }
    return getSubscribeOnMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PrivacyEventsServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceStub>() {
        @java.lang.Override
        public PrivacyEventsServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PrivacyEventsServiceStub(channel, callOptions);
        }
      };
    return PrivacyEventsServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PrivacyEventsServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceBlockingStub>() {
        @java.lang.Override
        public PrivacyEventsServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PrivacyEventsServiceBlockingStub(channel, callOptions);
        }
      };
    return PrivacyEventsServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PrivacyEventsServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PrivacyEventsServiceFutureStub>() {
        @java.lang.Override
        public PrivacyEventsServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PrivacyEventsServiceFutureStub(channel, callOptions);
        }
      };
    return PrivacyEventsServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubscribeOnMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service PrivacyEventsService.
   */
  public static abstract class PrivacyEventsServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return PrivacyEventsServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service PrivacyEventsService.
   */
  public static final class PrivacyEventsServiceStub
      extends io.grpc.stub.AbstractAsyncStub<PrivacyEventsServiceStub> {
    private PrivacyEventsServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceStub(channel, callOptions);
    }

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> responseObserver) {
      io.grpc.stub.ClientCalls.asyncServerStreamingCall(
          getChannel().newCall(getSubscribeOnMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service PrivacyEventsService.
   */
  public static final class PrivacyEventsServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<PrivacyEventsServiceBlockingStub> {
    private PrivacyEventsServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent> subscribeOn(
        com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request) {
      return io.grpc.stub.ClientCalls.blockingServerStreamingCall(
          getChannel(), getSubscribeOnMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service PrivacyEventsService.
   */
  public static final class PrivacyEventsServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<PrivacyEventsServiceFutureStub> {
    private PrivacyEventsServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PrivacyEventsServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PrivacyEventsServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_ON = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_ON:
          serviceImpl.subscribeOn((com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getSubscribeOnMethod(),
          io.grpc.stub.ServerCalls.asyncServerStreamingCall(
            new MethodHandlers<
              com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
              com.wavesenterprise.protobuf.service.privacy.PrivacyEvent>(
                service, METHODID_SUBSCRIBE_ON)))
        .build();
  }

  private static abstract class PrivacyEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PrivacyEventsServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.privacy.PrivacyEventsServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PrivacyEventsService");
    }
  }

  private static final class PrivacyEventsServiceFileDescriptorSupplier
      extends PrivacyEventsServiceBaseDescriptorSupplier {
    PrivacyEventsServiceFileDescriptorSupplier() {}
  }

  private static final class PrivacyEventsServiceMethodDescriptorSupplier
      extends PrivacyEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    PrivacyEventsServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PrivacyEventsServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PrivacyEventsServiceFileDescriptorSupplier())
              .addMethod(getSubscribeOnMethod())
              .build();
        }
      }
    }
    return result;
  }
}
